@@ -5,9 +5,9 @@ import typer
 
 def main(name: Optional[str] = typer.Argument(None)):
     if name is None:
-        typer.echo("Hello World!")
+        print("Hello World!")
     else:
-        typer.echo(f"Hello {name}")
+        print(f"Hello {name}")
 
 
 if __name__ == "__main__":
