@@ -6,7 +6,7 @@ def main(file: typer.FileBinaryRead = typer.Option(...)):
     for bytes_chunk in file:
         # Process the bytes in bytes_chunk
         processed_total += len(bytes_chunk)
-        typer.echo(f"Processed bytes total: {processed_total}")
+        print(f"Processed bytes total: {processed_total}")
 
 
 if __name__ == "__main__":
