@@ -2,7 +2,7 @@ import typer
 
 
 def main(verbose: int = typer.Option(0, "--verbose", "-v", count=True)):
-    typer.echo(f"Verbose level is {verbose}")
+    print(f"Verbose level is {verbose}")
 
 
 if __name__ == "__main__":
