@@ -15,7 +15,7 @@ def main(
     )
 ):
     text = config.read_text()
-    typer.echo(f"Config file contents: {text}")
+    print(f"Config file contents: {text}")
 
 
 if __name__ == "__main__":
