@@ -1,6 +1,7 @@
 import subprocess
 
 import typer
+import typer.core
 from typer.testing import CliRunner
 
 from docs_src.arguments.envvar import tutorial001 as mod
@@ -15,8 +16,21 @@ def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] [NAME]" in result.output
-    assert "Arguments:" in result.output
-    assert "[env var: AWESOME_NAME;default: World]" in result.output
+    assert "Arguments" in result.output
+    assert "env var: AWESOME_NAME" in result.output
+    assert "default: World" in result.output
+
+
+def test_help_no_rich():
+    rich = typer.core.rich
+    typer.core.rich = None
+    result = runner.invoke(app, ["--help"])
+    assert result.exit_code == 0
+    assert "[OPTIONS] [NAME]" in result.output
+    assert "Arguments" in result.output
+    assert "env var: AWESOME_NAME" in result.output
+    assert "default: World" in result.output
+    typer.core.rich = rich
 
 
 def test_call_arg():
