@@ -1,6 +1,7 @@
 import subprocess
 
 import typer
+import typer.core
 from typer.testing import CliRunner
 
 from docs_src.arguments.help import tutorial007 as mod
@@ -14,10 +15,9 @@ app.command()(mod.main)
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
-    assert "[OPTIONS] [NAME]" in result.output
     assert "Say hi to NAME very gently, like Dirk." in result.output
-    assert "Arguments:" not in result.output
-    assert "[default: World]" not in result.output
+    assert "Arguments" in result.output
+    assert "Secondary Arguments" in result.output
 
 
 def test_call_arg():
