@@ -35,7 +35,8 @@ def test_help_delete():
     assert result.exit_code == 0
     assert "delete [OPTIONS] USERNAME" in result.output
     assert "Delete a user with USERNAME." in result.output
-    assert "--force / --no-force" in result.output
+    assert "--force" in result.output
+    assert "--no-force" in result.output
     assert "Force deletion without confirmation." in result.output
 
 
@@ -46,7 +47,8 @@ def test_help_delete_all():
     assert "Delete ALL users in the database." in result.output
     assert "If --force is not used, will ask for confirmation." in result.output
     assert "[required]" in result.output
-    assert "--force / --no-force" in result.output
+    assert "--force" in result.output
+    assert "--no-force" in result.output
     assert "Force deletion without confirmation." in result.output
 
 
