@@ -12,7 +12,7 @@ runner = CliRunner()
 def test_no_arg():
     result = runner.invoke(app)
     assert result.exit_code != 0
-    assert "Error: Missing argument 'NAME'." in result.output
+    assert "Missing argument 'NAME'." in result.output
 
 
 def test_arg():
