@@ -13,7 +13,7 @@ def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] COMMAND [ARGS]..." in result.output
-    assert "Commands:" in result.output
+    assert "Commands" in result.output
     assert "create" in result.output
     assert "delete" in result.output
 
