@@ -12,16 +12,26 @@ app.command()(mod.main)
 
 
 def test_call():
-    result = runner.invoke(app)
+    result = runner.invoke(app, ["World"])
     assert result.exit_code == 0
-    assert "Hello Wade Wilson" in result.output
+    assert "Hello World" in result.output
+
+
+def test_formal():
+    result = runner.invoke(app, ["World", "--formal"])
+    assert result.exit_code == 0
+    assert "Good day Ms. World" in result.output
 
 
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
-    assert "--fullname TEXT" in result.output
-    assert "[default: Wade Wilson]" not in result.output
+    assert "--lastname" in result.output
+    assert "Customization and Utils" in result.output
+    assert "--formal" in result.output
+    assert "--no-formal" in result.output
+    assert "--debug" in result.output
+    assert "--no-debug" in result.output
 
 
 def test_script():
