@@ -27,7 +27,8 @@ def test_option_lastname_prompt():
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
-    assert "--lastname TEXT" in result.output
+    assert "--lastname" in result.output
+    assert "TEXT" in result.output
     assert "[required]" in result.output
 
 
