@@ -1,6 +1,7 @@
 import subprocess
 
 import typer
+import typer.core
 from typer.testing import CliRunner
 
 from docs_src.options.required import tutorial001 as mod
@@ -14,7 +15,7 @@ app.command()(mod.main)
 def test_1():
     result = runner.invoke(app, ["Camila"])
     assert result.exit_code != 0
-    assert "Error: Missing option '--lastname'." in result.output
+    assert "Missing option '--lastname'." in result.output
 
 
 def test_option_lastname():
@@ -26,10 +27,22 @@ def test_option_lastname():
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
-    assert "--lastname TEXT" in result.output
+    assert "--lastname" in result.output
+    assert "TEXT" in result.output
     assert "[required]" in result.output
 
 
+def test_help_no_rich():
+    rich = typer.core.rich
+    typer.core.rich = None
+    result = runner.invoke(app, ["--help"])
+    assert result.exit_code == 0
+    assert "--lastname" in result.output
+    assert "TEXT" in result.output
+    assert "[required]" in result.output
+    typer.core.rich = rich
+
+
 def test_script():
     result = subprocess.run(
         ["coverage", "run", mod.__file__, "--help"],
