@@ -27,13 +27,18 @@ def test_main():
 def test_invalid():
     result = runner.invoke(app, ["july-19-1989"])
     assert result.exit_code != 0
+    assert (
+        "Invalid value for 'BIRTH:[%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]':"
+        in result.stdout
+    )
     # TODO: when deprecating Click 7, remove second option
     assert (
-        "Error: Invalid value for 'BIRTH:[%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]': 'july-19-1989' does not match the formats '%Y-%m-%d', '%Y-%m-%dT%H:%M:%S', '%Y-%m-%d %H:%M:%S'"
-        in result.output
-        or "Error: Invalid value for 'BIRTH:[%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]': invalid datetime format: july-19-1989. (choose from %Y-%m-%d, %Y-%m-%dT%H:%M:%S, %Y-%m-%d %H:%M:%S)"
-        in result.output
+        "'july-19-1989' does not match the formats" in result.output
+        or "invalid datetime format: july-19-1989. (choose from" in result.output
     )
+    assert "%Y-%m-%d" in result.output
+    assert "%Y-%m-%dT%H:%M:%S" in result.output
+    assert "%Y-%m-%d %H:%M:%S" in result.output
 
 
 def test_script():
