@@ -14,7 +14,8 @@ app.command()(mod.main)
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
-    assert "--network [simple|conv|lstm]" in result.output
+    assert "--network" in result.output
+    assert "[simple|conv|lstm]" in result.output
 
 
 def test_main():
@@ -29,11 +30,13 @@ def test_invalid():
     # TODO: when deprecating Click 7, remove second option
 
     assert (
-        "Error: Invalid value for '--network': 'capsule' is not one of 'simple', 'conv', 'lstm'"
-        in result.output
-        or "Error: Invalid value for '--network': invalid choice: capsule. (choose from simple, conv, lstm)"
+        "Invalid value for '--network': 'capsule' is not one of" in result.output
+        or "Invalid value for '--network': invalid choice: capsule. (choose from"
         in result.output
     )
+    assert "simple" in result.output
+    assert "conv" in result.output
+    assert "lstm" in result.output
 
 
 def test_script():
