@@ -17,9 +17,8 @@ def test_invalid_id():
     # TODO: when deprecating Click 7, remove second option
 
     assert (
-        "Error: Invalid value for 'ID': 1002 is not in the range 0<=x<=1000"
-        in result.output
-        or "Error: Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
+        "Invalid value for 'ID': 1002 is not in the range 0<=x<=1000" in result.output
+        or "Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
         in result.output
     )
 
