@@ -3,7 +3,7 @@ import subprocess
 import typer
 from typer.testing import CliRunner
 
-from prompt import tutorial002 as mod
+from docs_src.prompt import tutorial002 as mod
 
 runner = CliRunner()
 
@@ -23,7 +23,7 @@ def test_no_confirm():
     assert result.exit_code == 1
     assert "Are you sure you want to delete it? [y/N]:" in result.output
     assert "Not deleting" in result.output
-    assert "Aborted!" in result.output
+    assert "Aborted" in result.output
 
 
 def test_script():
