@@ -4,6 +4,7 @@ import pytest
 from typer.testing import CliRunner
 
 from docs_src.subcommands import tutorial003
+from docs_src.subcommands.tutorial003 import items, users
 
 runner = CliRunner()
 
@@ -46,18 +47,30 @@ def test_items_create(app):
     result = runner.invoke(app, ["items", "create", "Wand"])
     assert result.exit_code == 0
     assert "Creating item: Wand" in result.output
+    # For coverage, becauses the monkeypatch above sometimes confuses coverage
+    result = runner.invoke(items.app, ["create", "Wand"])
+    assert result.exit_code == 0
+    assert "Creating item: Wand" in result.output
 
 
 def test_items_sell(app):
     result = runner.invoke(app, ["items", "sell", "Vase"])
     assert result.exit_code == 0
     assert "Selling item: Vase" in result.output
+    # For coverage, becauses the monkeypatch above sometimes confuses coverage
+    result = runner.invoke(items.app, ["sell", "Vase"])
+    assert result.exit_code == 0
+    assert "Selling item: Vase" in result.output
 
 
 def test_items_delete(app):
     result = runner.invoke(app, ["items", "delete", "Vase"])
     assert result.exit_code == 0
     assert "Deleting item: Vase" in result.output
+    # For coverage, becauses the monkeypatch above sometimes confuses coverage
+    result = runner.invoke(items.app, ["delete", "Vase"])
+    assert result.exit_code == 0
+    assert "Deleting item: Vase" in result.output
 
 
 def test_help_users(app):
@@ -74,12 +87,20 @@ def test_users_create(app):
     result = runner.invoke(app, ["users", "create", "Camila"])
     assert result.exit_code == 0
     assert "Creating user: Camila" in result.output
+    # For coverage, becauses the monkeypatch above sometimes confuses coverage
+    result = runner.invoke(users.app, ["create", "Camila"])
+    assert result.exit_code == 0
+    assert "Creating user: Camila" in result.output
 
 
 def test_users_delete(app):
     result = runner.invoke(app, ["users", "delete", "Camila"])
     assert result.exit_code == 0
     assert "Deleting user: Camila" in result.output
+    # For coverage, becauses the monkeypatch above sometimes confuses coverage
+    result = runner.invoke(users.app, ["delete", "Camila"])
+    assert result.exit_code == 0
+    assert "Deleting user: Camila" in result.output
 
 
 def test_help_lands(app):
