@@ -1,6 +1,7 @@
 import subprocess
 
 import typer
+import typer.core
 from typer.testing import CliRunner
 
 from docs_src.terminating import tutorial003 as mod
@@ -21,7 +22,24 @@ def test_root():
     result = runner.invoke(app, ["root"])
     assert result.exit_code == 1
     assert "The root user is reserved" in result.output
-    assert "Aborted!" in result.output
+    assert "Aborted" in result.output
+
+
+def test_root_no_standalone():
+    # Mainly for coverage
+    result = runner.invoke(app, ["root"], standalone_mode=False)
+    assert result.exit_code == 1
+
+
+def test_root_no_rich():
+    # Mainly for coverage
+    rich = typer.core.rich
+    typer.core.rich = None
+    result = runner.invoke(app, ["root"])
+    assert result.exit_code == 1
+    assert "The root user is reserved" in result.stdout
+    assert "Aborted!" in result.stdout
+    typer.core.rich = rich
 
 
 def test_script():
